Useful Functions
================

Miscellaneous useful auxiliary functions:


.. autofunction:: pyimfit.get_function_list


.. autofunction:: pyimfit.get_function_dict


.. autofunction:: pyimfit.make_imfit_function


.. autofunction:: pyimfit.parse_config_file


.. autofunction:: pyimfit.parse_config


.. autofunction:: pyimfit.MakePsfOversampler


.. autofunction:: pyimfit.FixImage

